Entry

Enum Entry 

pub enum Entry<'a, K, V> {
    Vacant(VacantEntry<'a, K, V>),
    Occupied(OccupiedEntry<'a, K, V>),
}
A view into a single key position in an AList.

Variants



Vacant(VacantEntry<'a, K, V>)

The key is not present and can be inserted.



Occupied(OccupiedEntry<'a, K, V>)

The key is present and its value can be read, modified, or removed.

Implementations

Source

impl<'a, K, V> Entry<'a, K, V>

pub fn or_insert(self, default: V) -> &'a mut V

Ensures a value is present and returns a mutable reference to it.

Inserts default when this entry is vacant. Existing values are left unchanged.

pub fn or_insert_with<F: FnOnce() -> V>(self, default: F) -> &'a mut V

Ensures a value is present using a lazily evaluated default.

The closure is called only when this entry is vacant.

pub fn or_insert_with_key<F: FnOnce(&K) -> V>(self, default: F) -> &'a mut V

Ensures a value is present using a default derived from the entry key.

The closure is called only when this entry is vacant.

pub fn key(&self) -> &K

Returns a reference to the entry key.

pub fn and_modify<F>(self, f: F) -> Self
where F: FnOnce(&mut V),

Modifies an occupied value in place.

Vacant entries are left unchanged, allowing fluent entry chains.

Source

impl<'a, K, V: Default> Entry<'a, K, V>

pub fn or_default(self) -> &'a mut V

Ensures a value is present by inserting Default::default when vacant.