pub enum Entry<'a, K, V> {
Vacant(VacantEntry<'a, K, V>),
Occupied(OccupiedEntry<'a, K, V>),
}Expand description
A view into a single key position in an AList.
Variants
Vacant(VacantEntry<'a, K, V>)
The key is not present and can be inserted.
Occupied(OccupiedEntry<'a, K, V>)
The key is present and its value can be read, modified, or removed.
Implementations
Sourceimpl<'a, K, V> Entry<'a, K, V>
impl<'a, K, V> Entry<'a, K, V>
Sourcepub fn or_insert(self, default: V) -> &'a mut V
pub fn or_insert(self, default: V) -> &'a mut V
Ensures a value is present and returns a mutable reference to it.
Inserts default when this entry is vacant. Existing values are left
unchanged.
Sourcepub fn or_insert_with<F: FnOnce() -> V>(self, default: F) -> &'a mut V
pub fn or_insert_with<F: FnOnce() -> V>(self, default: F) -> &'a mut V
Ensures a value is present using a lazily evaluated default.
The closure is called only when this entry is vacant.
Sourcepub fn or_insert_with_key<F: FnOnce(&K) -> V>(self, default: F) -> &'a mut V
pub fn or_insert_with_key<F: FnOnce(&K) -> V>(self, default: F) -> &'a mut V
Ensures a value is present using a default derived from the entry key.
The closure is called only when this entry is vacant.
Sourcepub fn and_modify<F>(self, f: F) -> Self
pub fn and_modify<F>(self, f: F) -> Self
Modifies an occupied value in place.
Vacant entries are left unchanged, allowing fluent entry chains.
Sourceimpl<'a, K, V: Default> Entry<'a, K, V>
impl<'a, K, V: Default> Entry<'a, K, V>
Sourcepub fn or_default(self) -> &'a mut V
pub fn or_default(self) -> &'a mut V
Ensures a value is present by inserting Default::default when vacant.